import typing
import collections.abc

GenericType1 = typing.TypeVar("GenericType1")
GenericType2 = typing.TypeVar("GenericType2")

def generate(context, space_type, use_fallback_keys=True, use_reset=True):
    """Keymap for popup toolbar, currently generated each time."""

    ...
